        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,7,10,11,13,16,17,18,20,21,22,27,29,31,33,34,38,40,42,43,44,46,48,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 13 <br>1,5,6,12,14,15,23,24,25,30,32,41,50';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,9,19,26,28,35,36,37,39,45,47';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,7,10,11,13,16,17,18,20,21,22,27,29,31,33,34,38,40,42,43,44,46,48,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 13 <br>1,5,6,12,14,15,23,24,25,30,32,41,50';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,9,19,26,28,35,36,37,39,45,47';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,7,10,11,13,16,17,18,20,21,22,27,29,31,33,34,38,40,42,43,44,46,48,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 13 <br>1,5,6,12,14,15,23,24,25,30,32,41,50';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,9,19,26,28,35,36,37,39,45,47';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,7,10,11,13,16,17,18,20,21,22,27,29,31,33,34,38,40,42,43,44,46,48,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 13 <br>1,5,6,12,14,15,23,24,25,30,32,41,50';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,9,19,26,28,35,36,37,39,45,47';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,7,10,11,13,16,17,18,20,21,22,27,29,31,33,34,38,40,42,43,44,46,48,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 13 <br>1,5,6,12,14,15,23,24,25,30,32,41,50';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,9,19,26,28,35,36,37,39,45,47';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,7,10,11,13,16,17,18,20,21,22,27,29,31,33,34,38,40,42,43,44,46,48,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 13 <br>1,5,6,12,14,15,23,24,25,30,32,41,50';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,9,19,26,28,35,36,37,39,45,47';}
}
