        function getR(rrw){
           cx=0;
       cx+=1;
       if(rrw==cx){return 7;}
       cx+=1;
       if(rrw==cx){return 34;}
       cx+=1;
       if(rrw==cx){return 35;}
       cx+=1;
       if(rrw==cx){return 36;}
       cx+=1;
       if(rrw==cx){return 37;}
       cx+=1;
       if(rrw==cx){return 38;}
       cx+=1;
       if(rrw==cx){return 39;}
return -1;}
